==> ShortRead_1.6.2.zip: ShortRead/doc/Overview.R <==
###################################################
### chunk number 1: options
###################################################
options(width=60)


###################################################
### chunk number 2: preliminaries
###################################################
library("ShortRead")


###################################################
### chunk number 3: SolexaPath-root
###################################################
exptPath <- system.file("extdata", package="ShortRead")


###################################################
### chunk number 4: SolexaPat
###################################################
sp <- SolexaPath(exptPath)
sp


###################################################
### chunk number 5: firecrest
###################################################
imageAnalysisPath(sp)
analysisPath(sp)


###################################################
### chunk number 6: readAligned-simple
###################################################
aln <- readAligned(sp, "s_2_export.txt")
aln


###################################################
### chunk number 7: filter-egs
###################################################
nfilt <- nFilter()
cfilt <- chromosomeFilter('chr5.fa')
sfilt <- strandFilter("+")
ofilt <- occurrenceFilter(withSread=FALSE)


###################################################
### chunk number 8: readAligned-filter
###################################################
chr5 <- readAligned(sp, "s_2_export.txt", filter=cfilt)


###################################################
### chunk number 9: readAligned-compose-filter
###################################################
filt <- compose(cfilt, sfilt)
chr5plus <- readAligned(sp, "s_2_export.txt", filter=filt)


###################################################
### chunk number 10: AlignedRead-filter
###################################################
chr5 <- aln[cfilt(aln)]


###################################################
### chunk number 11: aln-sread-quality
###################################################
sread(aln)
quality(aln)


###################################################
### chunk number 12: chromosomes
###################################################
whichStrand <- strand(aln)
class(whichStrand)
levels(whichStrand)
table(whichStrand, useNA="ifany")


###################################################
### chunk number 13: alignData
###################################################
alignData(aln)


###################################################
### chunk number 14: varMetadata
###################################################
varMetadata(alignData(aln))


###################################################
### chunk number 15: aln-okreads
###################################################
mapped <- !is.na(position(aln))
filtered <- alignData(aln)[["filtering"]] =="Y"
sum(!mapped) / length(aln)
sum(filtered) / length(aln)


###################################################
### chunk number 16: aln-failed
###################################################
failedAlign <- aln[filtered & !mapped]
failedAlign


###################################################
### chunk number 17: sread-filter-fail-subset
###################################################
failedReads <- sread(aln)[filtered & !mapped]


###################################################
### chunk number 18: qa
###################################################
qaSummary <- qa(sp)


###################################################
### chunk number 19:  eval=FALSE
###################################################
## save(qaSummary, file="/path/to/file.rda")


###################################################
### chunk number 20:  eval=FALSE
###################################################
## library("Rmpi")
## mpi.spawn.Rslaves(nsl=8)
## qaSummary <- qa(sp)
## mpi.close.Rslaves()


###################################################
### chunk number 21:  eval=FALSE
###################################################
## library(multicore)
## qaSummary <- qa(sp)


###################################################
### chunk number 22: qa-elements
###################################################
qaSummary


###################################################
### chunk number 23: qa-readCounts
###################################################
qaSummary[["readCounts"]]
qaSummary[["baseCalls"]]


###################################################
### chunk number 24: report eval=FALSE
###################################################
## report(qaSummary, dest="/path/to/report_directory")


###################################################
### chunk number 25: export
###################################################
pattern <- "s_2_export.txt"
fl <- file.path(analysisPath(sp), pattern)
strsplit(readLines(fl, n=1), "\t")
length(readLines(fl))


###################################################
### chunk number 26: colClasses
###################################################
colClasses <- rep(list(NULL), 21)
colClasses[9:10] <- c("DNAString", "BString")
names(colClasses)[9:10] <- c("read", "quality")


###################################################
### chunk number 27: readXStringColumns
###################################################
cols <- readXStringColumns(analysisPath(sp), pattern, colClasses)
cols


###################################################
### chunk number 28: size
###################################################
object.size(cols$read)
object.size(as.character(cols$read))


###################################################
### chunk number 29: fastq-format
###################################################
fqpattern <- "s_1_sequence.txt"
fl <- file.path(analysisPath(sp), fqpattern)
readLines(fl, 4)


###################################################
### chunk number 30: readFastq
###################################################
fq <- readFastq(sp, fqpattern)
fq


###################################################
### chunk number 31: ShortReadQ
###################################################
reads <- sread(fq)
qualities <- quality(fq)
class(qualities)
id(fq)


###################################################
### chunk number 32: ShortReadQ-subset
###################################################
fq[1:5]


###################################################
### chunk number 33: intensity-files
###################################################
int <- readIntensities(sp, withVariability=FALSE)
int


###################################################
### chunk number 34: intensities-cycle-2
###################################################
print(splom(intensity(int)[[,,2]], pch=".", cex=3))


###################################################
### chunk number 35: tables
###################################################
tbls <- tables(aln)
names(tbls)
tbls$top[1:5]
head(tbls$distribution)


###################################################
### chunk number 36: srdistance
###################################################
dist <- srdistance(sread(aln), names(tbls$top)[1])[[1]]
table(dist)[1:10]


###################################################
### chunk number 37: aln-not-near
###################################################
alnSubset <- aln[dist>4]


###################################################
### chunk number 38: polya
###################################################
countA <- alphabetFrequency(sread(aln))[,"A"] 
alnNoPolyA <- aln[countA < 30]


###################################################
### chunk number 39: readSeq
###################################################
seqFls <- list.files(baseCallPath(sp), "_seq.txt", full=TRUE)
strsplit(readLines(seqFls[[1]], 1), "\t")
colClasses <- c(rep(list(NULL), 4), "DNAString")
reads <- readXStringColumns(baseCallPath(sp), "s_1_0001_seq.txt",
                            colClasses=colClasses)


###################################################
### chunk number 40: readSeq-all
###################################################
reads <- readXStringColumns(baseCallPath(sp), "s_1_.*_seq.txt",
                            colClasses=colClasses)


###################################################
### chunk number 41: calcInt-demo
###################################################
calcInt <- function(file, cycle, verbose=FALSE)
{
    if (verbose)
        cat("calcInt", file, cycle, "\n")
    int <- readIntensities(dirname(file), basename(file),
                           intExtension="", withVariability=FALSE)
    apply(intensity(int)[,,12], 2, mean)
}


###################################################
### chunk number 42: calcInt-sapply
###################################################
intFls <- list.files(imageAnalysisPath(sp), ".*_int.txt$", full=TRUE)
lres <- lapply(intFls, calcInt, cycle=12)


###################################################
### chunk number 43: srapply-simple
###################################################
srres <- srapply(intFls, calcInt, cycle=12)
identical(lres, srres)


###################################################
### chunk number 44: srapply-mpi eval=FALSE
###################################################
## library("Rmpi")
## mpi.spawn.Rslaves(nsl=16)
## srres <- srapply(intFls, calcInt, cycle=12)
## mpi.close.Rslaves()


###################################################
### chunk number 45: srapply-multicore eval=FALSE
###################################################
## library(multicore)
## srres <- srapply(intFls, calcInt, cycle=12)


###################################################
### chunk number 46: sessionInfo
###################################################
toLatex(sessionInfo())

==> ShortRead_1.8.2.zip: ShortRead/doc/Overview.R <==
###################################################
### chunk number 1: options
###################################################
#line 35 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp5Ryo3O/R.INSTALL32f25189/ShortRead/inst/doc/Overview.Rnw"
options(width=60)


###################################################
### chunk number 2: preliminaries
###################################################
#line 39 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp5Ryo3O/R.INSTALL32f25189/ShortRead/inst/doc/Overview.Rnw"
library("ShortRead")


###################################################
### chunk number 3: SolexaPath-root
###################################################
#line 65 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp5Ryo3O/R.INSTALL32f25189/ShortRead/inst/doc/Overview.Rnw"
exptPath <- system.file("extdata", package="ShortRead")


###################################################
### chunk number 4: SolexaPat
###################################################
#line 71 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp5Ryo3O/R.INSTALL32f25189/ShortRead/inst/doc/Overview.Rnw"
sp <- SolexaPath(exptPath)
sp


###################################################
### chunk number 5: firecrest
###################################################
#line 80 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp5Ryo3O/R.INSTALL32f25189/ShortRead/inst/doc/Overview.Rnw"
imageAnalysisPath(sp)
analysisPath(sp)


###################################################
### chunk number 6: readAligned-simple
###################################################
#line 114 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp5Ryo3O/R.INSTALL32f25189/ShortRead/inst/doc/Overview.Rnw"
aln <- readAligned(sp, "s_2_export.txt")
aln


###################################################
### chunk number 7: filter-egs
###################################################
#line 219 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp5Ryo3O/R.INSTALL32f25189/ShortRead/inst/doc/Overview.Rnw"
nfilt <- nFilter()
cfilt <- chromosomeFilter('chr5.fa')
sfilt <- strandFilter("+")
ofilt <- occurrenceFilter(withSread=FALSE)


###################################################
### chunk number 8: readAligned-filter
###################################################
#line 227 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp5Ryo3O/R.INSTALL32f25189/ShortRead/inst/doc/Overview.Rnw"
chr5 <- readAligned(sp, "s_2_export.txt", filter=cfilt)


###################################################
### chunk number 9: readAligned-compose-filter
###################################################
#line 233 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp5Ryo3O/R.INSTALL32f25189/ShortRead/inst/doc/Overview.Rnw"
filt <- compose(cfilt, sfilt)
chr5plus <- readAligned(sp, "s_2_export.txt", filter=filt)


###################################################
### chunk number 10: AlignedRead-filter
###################################################
#line 240 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp5Ryo3O/R.INSTALL32f25189/ShortRead/inst/doc/Overview.Rnw"
chr5 <- aln[cfilt(aln)]


###################################################
### chunk number 11: aln-sread-quality
###################################################
#line 254 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp5Ryo3O/R.INSTALL32f25189/ShortRead/inst/doc/Overview.Rnw"
sread(aln)
quality(aln)


###################################################
### chunk number 12: chromosomes
###################################################
#line 287 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp5Ryo3O/R.INSTALL32f25189/ShortRead/inst/doc/Overview.Rnw"
whichStrand <- strand(aln)
class(whichStrand)
levels(whichStrand)
table(whichStrand, useNA="ifany")


###################################################
### chunk number 13: alignData
###################################################
#line 303 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp5Ryo3O/R.INSTALL32f25189/ShortRead/inst/doc/Overview.Rnw"
alignData(aln)


###################################################
### chunk number 14: varMetadata
###################################################
#line 313 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp5Ryo3O/R.INSTALL32f25189/ShortRead/inst/doc/Overview.Rnw"
varMetadata(alignData(aln))


###################################################
### chunk number 15: aln-okreads
###################################################
#line 326 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp5Ryo3O/R.INSTALL32f25189/ShortRead/inst/doc/Overview.Rnw"
mapped <- !is.na(position(aln))
filtered <- alignData(aln)[["filtering"]] =="Y"
sum(!mapped) / length(aln)
sum(filtered) / length(aln)


###################################################
### chunk number 16: aln-failed
###################################################
#line 335 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp5Ryo3O/R.INSTALL32f25189/ShortRead/inst/doc/Overview.Rnw"
failedAlign <- aln[filtered & !mapped]
failedAlign


###################################################
### chunk number 17: sread-filter-fail-subset
###################################################
#line 342 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp5Ryo3O/R.INSTALL32f25189/ShortRead/inst/doc/Overview.Rnw"
failedReads <- sread(aln)[filtered & !mapped]


###################################################
### chunk number 18: qa
###################################################
#line 351 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp5Ryo3O/R.INSTALL32f25189/ShortRead/inst/doc/Overview.Rnw"
qaSummary <- qa(sp)


###################################################
### chunk number 19:  eval=FALSE
###################################################
## #line 364 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp5Ryo3O/R.INSTALL32f25189/ShortRead/inst/doc/Overview.Rnw"
## save(qaSummary, file="/path/to/file.rda")


###################################################
### chunk number 20:  eval=FALSE
###################################################
## #line 371 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp5Ryo3O/R.INSTALL32f25189/ShortRead/inst/doc/Overview.Rnw"
## library("Rmpi")
## mpi.spawn.Rslaves(nsl=8)
## qaSummary <- qa(sp)
## mpi.close.Rslaves()


###################################################
### chunk number 21:  eval=FALSE
###################################################
## #line 379 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp5Ryo3O/R.INSTALL32f25189/ShortRead/inst/doc/Overview.Rnw"
## library(multicore)
## qaSummary <- qa(sp)


###################################################
### chunk number 22: qa-elements
###################################################
#line 393 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp5Ryo3O/R.INSTALL32f25189/ShortRead/inst/doc/Overview.Rnw"
qaSummary


###################################################
### chunk number 23: qa-readCounts
###################################################
#line 399 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp5Ryo3O/R.INSTALL32f25189/ShortRead/inst/doc/Overview.Rnw"
qaSummary[["readCounts"]]
qaSummary[["baseCalls"]]


###################################################
### chunk number 24: report eval=FALSE
###################################################
## #line 416 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp5Ryo3O/R.INSTALL32f25189/ShortRead/inst/doc/Overview.Rnw"
## report(qaSummary, dest="/path/to/report_directory")


###################################################
### chunk number 25: export
###################################################
#line 452 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp5Ryo3O/R.INSTALL32f25189/ShortRead/inst/doc/Overview.Rnw"
pattern <- "s_2_export.txt"
fl <- file.path(analysisPath(sp), pattern)
strsplit(readLines(fl, n=1), "\t")
length(readLines(fl))


###################################################
### chunk number 26: colClasses
###################################################
#line 481 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp5Ryo3O/R.INSTALL32f25189/ShortRead/inst/doc/Overview.Rnw"
colClasses <- rep(list(NULL), 21)
colClasses[9:10] <- c("DNAString", "BString")
names(colClasses)[9:10] <- c("read", "quality")


###################################################
### chunk number 27: readXStringColumns
###################################################
#line 492 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp5Ryo3O/R.INSTALL32f25189/ShortRead/inst/doc/Overview.Rnw"
cols <- readXStringColumns(analysisPath(sp), pattern, colClasses)
cols


###################################################
### chunk number 28: size
###################################################
#line 509 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp5Ryo3O/R.INSTALL32f25189/ShortRead/inst/doc/Overview.Rnw"
object.size(cols$read)
object.size(as.character(cols$read))


###################################################
### chunk number 29: fastq-format
###################################################
#line 525 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp5Ryo3O/R.INSTALL32f25189/ShortRead/inst/doc/Overview.Rnw"
fqpattern <- "s_1_sequence.txt"
fl <- file.path(analysisPath(sp), fqpattern)
readLines(fl, 4)


###################################################
### chunk number 30: readFastq
###################################################
#line 535 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp5Ryo3O/R.INSTALL32f25189/ShortRead/inst/doc/Overview.Rnw"
fq <- readFastq(sp, fqpattern)
fq


###################################################
### chunk number 31: ShortReadQ
###################################################
#line 542 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp5Ryo3O/R.INSTALL32f25189/ShortRead/inst/doc/Overview.Rnw"
reads <- sread(fq)
qualities <- quality(fq)
class(qualities)
id(fq)


###################################################
### chunk number 32: ShortReadQ-subset
###################################################
#line 555 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp5Ryo3O/R.INSTALL32f25189/ShortRead/inst/doc/Overview.Rnw"
fq[1:5]


###################################################
### chunk number 33: intensity-files
###################################################
#line 576 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp5Ryo3O/R.INSTALL32f25189/ShortRead/inst/doc/Overview.Rnw"
int <- readIntensities(sp, withVariability=FALSE)
int


###################################################
### chunk number 34: intensities-cycle-2
###################################################
#line 583 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp5Ryo3O/R.INSTALL32f25189/ShortRead/inst/doc/Overview.Rnw"
print(splom(intensity(int)[[,,2]], pch=".", cex=3))


###################################################
### chunk number 35: tables
###################################################
#line 611 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp5Ryo3O/R.INSTALL32f25189/ShortRead/inst/doc/Overview.Rnw"
tbls <- tables(aln)
names(tbls)
tbls$top[1:5]
head(tbls$distribution)


###################################################
### chunk number 36: srdistance
###################################################
#line 637 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp5Ryo3O/R.INSTALL32f25189/ShortRead/inst/doc/Overview.Rnw"
dist <- srdistance(sread(aln), names(tbls$top)[1])[[1]]
table(dist)[1:10]


###################################################
### chunk number 37: aln-not-near
###################################################
#line 643 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp5Ryo3O/R.INSTALL32f25189/ShortRead/inst/doc/Overview.Rnw"
alnSubset <- aln[dist>4]


###################################################
### chunk number 38: polya
###################################################
#line 652 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp5Ryo3O/R.INSTALL32f25189/ShortRead/inst/doc/Overview.Rnw"
countA <- alphabetFrequency(sread(aln))[,"A"] 
alnNoPolyA <- aln[countA < 30]


###################################################
### chunk number 39: readSeq
###################################################
#line 741 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp5Ryo3O/R.INSTALL32f25189/ShortRead/inst/doc/Overview.Rnw"
seqFls <- list.files(baseCallPath(sp), "_seq.txt", full=TRUE)
strsplit(readLines(seqFls[[1]], 1), "\t")
colClasses <- c(rep(list(NULL), 4), "DNAString")
reads <- readXStringColumns(baseCallPath(sp), "s_1_0001_seq.txt",
                            colClasses=colClasses)


###################################################
### chunk number 40: readSeq-all
###################################################
#line 750 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp5Ryo3O/R.INSTALL32f25189/ShortRead/inst/doc/Overview.Rnw"
reads <- readXStringColumns(baseCallPath(sp), "s_1_.*_seq.txt",
                            colClasses=colClasses)


###################################################
### chunk number 41: calcInt-demo
###################################################
#line 765 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp5Ryo3O/R.INSTALL32f25189/ShortRead/inst/doc/Overview.Rnw"
calcInt <- function(file, cycle, verbose=FALSE)
{
    if (verbose)
        cat("calcInt", file, cycle, "\n")
    int <- readIntensities(dirname(file), basename(file),
                           intExtension="", withVariability=FALSE)
    apply(intensity(int)[,,12], 2, mean)
}


###################################################
### chunk number 42: calcInt-sapply
###################################################
#line 777 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp5Ryo3O/R.INSTALL32f25189/ShortRead/inst/doc/Overview.Rnw"
intFls <- list.files(imageAnalysisPath(sp), ".*_int.txt$", full=TRUE)
lres <- lapply(intFls, calcInt, cycle=12)


###################################################
### chunk number 43: srapply-simple
###################################################
#line 787 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp5Ryo3O/R.INSTALL32f25189/ShortRead/inst/doc/Overview.Rnw"
srres <- srapply(intFls, calcInt, cycle=12)
identical(lres, srres)


###################################################
### chunk number 44: srapply-mpi eval=FALSE
###################################################
## #line 793 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp5Ryo3O/R.INSTALL32f25189/ShortRead/inst/doc/Overview.Rnw"
## library("Rmpi")
## mpi.spawn.Rslaves(nsl=16)
## srres <- srapply(intFls, calcInt, cycle=12)
## mpi.close.Rslaves()


###################################################
### chunk number 45: srapply-multicore eval=FALSE
###################################################
## #line 801 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp5Ryo3O/R.INSTALL32f25189/ShortRead/inst/doc/Overview.Rnw"
## library(multicore)
## srres <- srapply(intFls, calcInt, cycle=12)


###################################################
### chunk number 46: sessionInfo
###################################################
#line 827 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp5Ryo3O/R.INSTALL32f25189/ShortRead/inst/doc/Overview.Rnw"
toLatex(sessionInfo())
